package com.css.simulation.resource.monitor.scheduler;

import api.common.pojo.dto.Host;
import api.common.pojo.po.home.SystemServerPO;
import api.common.util.SshUtil;
import api.common.util.StringUtil;
import com.css.simulation.resource.monitor.mappper.SystemServerMapper;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.sshd.client.SshClient;
import org.apache.sshd.client.session.ClientSession;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
@ConfigurationProperties(prefix = "ssh")
@Data
@Slf4j
public class MyScheduler {

    List<Host> hostList;

    @Autowired
    SystemServerMapper systemServerManager;


//    @Scheduled(fixedDelay = 60 * 60 * 1000)
    @Scheduled(fixedDelay = 2 * 1000)
    public void server() {

        log.info("MyScheduler-------server 获取服务器信息！");


        hostList.forEach(host -> {

            String ip = host.getHostname();
            Integer port = host.getPort();
            String username = host.getUsername();
            String password = host.getPassword();
            String type = host.getType();

            try {
                SshClient sshClient = SshUtil.getClient();
                ClientSession session = SshUtil.getSession(sshClient, ip, username, password);
                int taskNumber = 0;
                if ("gpu".equals(type)) {
                    String podList = SshUtil.execute(session, "kubectl get pod | grep project");
                    taskNumber = StringUtil.countSubString(podList, "project");
                }

                SystemServerPO systemServerPO = SystemServerPO.builder()
                        .id(StringUtil.getRandomUUID())
                        .serverId(SshUtil.hostname(session))
                        .serverAddress(ip)
                        .serverType(type)
                        .memoryUsage(SshUtil.memoryUsage(session))
                        .memoryAvailable(SshUtil.memoryAvailable(session))
                        .memoryTotal(SshUtil.memoryTotal(session))
                        .diskUsage(SshUtil.diskUsage(session))
                        .diskAvailable(SshUtil.diskAvailable(session))
                        .diskTotal(SshUtil.diskTotal(session))
                        .cpuUsage(SshUtil.cpuUsage(session))
                        .cpuTotal(SshUtil.cpuTotal(session))
                        .gpuUsage(SshUtil.gpuUsage(session))
                        .gpuTotal(SshUtil.gpuTotal(session))
                        .taskNumber(taskNumber)
                        .build();

                systemServerManager.insert(systemServerPO);
            } catch (Exception e) {
                e.printStackTrace();
            }
        });


    }


}
